v1.4 - Nautobot ChatOps Documentation

Skip to content

# v1.4 Release Notes

## v1.4.0

Updates Nautobot ChatOps name for Webex Teams to Webex. As part of Cisco's renaming of Webex Teams to just Webex, the underlying configuration was updated.

### Fixes

#68) Correct var names for Nautobot #61) Mattermost sending interactive Dialog

### Updates

#63) Add additional Breadcrumbs #24 Rename Webex Teams to Webex

## v1.4.1

Minor update to better handle the versioning. This fixes an issue where the version number within Nautobot was not updated alongside the pyproject.toml.